@@ -9,7 +9,7 @@ use wasmer::*;
 /// The options for the `wasmer validate` subcommand
 pub struct Inspect {
     /// File to validate as WebAssembly
-    #[clap(name = "FILE", parse(from_os_str))]
+    #[clap(name = "FILE")]
     path: PathBuf,
 
     #[clap(flatten)]
@@ -22,6 +22,7 @@ impl Inspect {
         self.inner_execute()
             .context(format!("failed to inspect `{}`", self.path.display()))
     }
+
     fn inner_execute(&self) -> Result<()> {
         let (store, _compiler_type) = self.store.get_store()?;
         let module_contents = std::fs::read(&self.path)?;
