@@ -617,7 +617,7 @@ impl RemoteNetworkingServerDriver {
 
         // Now we attach the handler to the main listening socket
         let mut handler = Box::new(self.common.handler.clone().for_socket(socket_id));
-        handler.interest(virtual_mio::InterestType::Readable);
+        handler.push_interest(virtual_mio::InterestType::Readable);
         self.process_inner_noop(
             move |socket| match socket {
                 RemoteAdapterSocket::TcpListener {
@@ -1034,6 +1034,46 @@ impl RemoteNetworkingServerDriver {
                 socket_id,
                 req_id,
             ),
+            RequestType::SetKeepAlive(val) => self.process_inner_noop(
+                move |socket| match socket {
+                    RemoteAdapterSocket::TcpSocket(s) => s.set_keepalive(val),
+                    _ => Err(NetworkError::Unsupported),
+                },
+                socket_id,
+                req_id,
+            ),
+            RequestType::GetKeepAlive => self.process_inner(
+                move |socket| match socket {
+                    RemoteAdapterSocket::TcpSocket(s) => s.keepalive(),
+                    _ => Err(NetworkError::Unsupported),
+                },
+                |ret| match ret {
+                    Ok(flag) => ResponseType::Flag(flag),
+                    Err(err) => ResponseType::Err(err),
+                },
+                socket_id,
+                req_id,
+            ),
+            RequestType::SetDontRoute(val) => self.process_inner_noop(
+                move |socket| match socket {
+                    RemoteAdapterSocket::TcpSocket(s) => s.set_dontroute(val),
+                    _ => Err(NetworkError::Unsupported),
+                },
+                socket_id,
+                req_id,
+            ),
+            RequestType::GetDontRoute => self.process_inner(
+                move |socket| match socket {
+                    RemoteAdapterSocket::TcpSocket(s) => s.dontroute(),
+                    _ => Err(NetworkError::Unsupported),
+                },
+                |ret| match ret {
+                    Ok(flag) => ResponseType::Flag(flag),
+                    Err(err) => ResponseType::Err(err),
+                },
+                socket_id,
+                req_id,
+            ),
             RequestType::Shutdown(shutdown) => self.process_inner_noop(
                 move |socket| match socket {
                     RemoteAdapterSocket::TcpSocket(s) => s.shutdown(match shutdown {
@@ -1534,7 +1574,7 @@ impl RemoteAdapterHandler {
     }
 }
 impl InterestHandler for RemoteAdapterHandler {
-    fn interest(&mut self, interest: virtual_mio::InterestType) {
+    fn push_interest(&mut self, interest: virtual_mio::InterestType) {
         let mut guard = self.state.lock().unwrap();
         guard.driver_wakers.drain(..).for_each(|w| w.wake());
         let socket_id = match self.socket_id {
@@ -1545,6 +1585,30 @@ impl InterestHandler for RemoteAdapterHandler {
             guard.readable.insert(socket_id);
         }
     }
+
+    fn pop_interest(&mut self, interest: virtual_mio::InterestType) -> bool {
+        let mut guard = self.state.lock().unwrap();
+        let socket_id = match self.socket_id {
+            Some(s) => s,
+            None => return false,
+        };
+        if interest == virtual_mio::InterestType::Readable {
+            return guard.readable.remove(&socket_id);
+        }
+        false
+    }
+
+    fn has_interest(&self, interest: virtual_mio::InterestType) -> bool {
+        let guard = self.state.lock().unwrap();
+        let socket_id = match self.socket_id {
+            Some(s) => s,
+            None => return false,
+        };
+        if interest == virtual_mio::InterestType::Readable {
+            return guard.readable.contains(&socket_id);
+        }
+        false
+    }
 }
 
 type SocketMap<T> = HashMap<SocketId, T>;
