@@ -1,8 +1,9 @@
 mod builtin_loader;
 mod load_package_tree;
 mod types;
+mod unsupported;
 
 pub use self::{
     builtin_loader::BuiltinPackageLoader, load_package_tree::load_package_tree,
-    types::PackageLoader,
+    types::PackageLoader, unsupported::UnsupportedPackageLoader,
 };
